@@ -424,6 +424,10 @@ EAction.prototype.initUiOptions = function(resume, optionsToolBar) {
     var children = optionsToolBar.children();
     for (var i=0; i<children.length; i++) {
         var child = children[i];
+        if (isNull(child)) {
+            continue;
+        }
+
         var shortCut = child.shortcut;
         if (!isNull(shortCut) && !shortCut.isEmpty()) {
             var str = shortCut.toString();
@@ -538,6 +542,10 @@ EAction.prototype.hideOptionsToolBarWidgets = function(widgets, noSyncWidgets) {
     var children = optionsToolBar.children();
     for (i = 0; i < children.length; ++i) {
         c = children[i];
+        if (isNull(c)) {
+            continue;
+        }
+
         if (c["HideInDialogMode"]===true) {
             destr(c);
         }
@@ -786,6 +794,16 @@ EAction.prototype.setCursor = function(cursor, name) {
     if (!isNull(di)) {
         di.setCursor(cursor);
     }
+    var appWin = EAction.getMainWindow();
+    if (!isNull(appWin)) {
+        if (isNull(name)) {
+            appWin.setProperty("MouseCursor", "");
+        }
+        else {
+            appWin.setProperty("MouseCursor", name);
+        }
+    }
+
 //    if (!isNull(name)) {
 //        var views = this.getGraphicsViews();
 //        for (var i=0; i<views.length; i++) {
@@ -973,9 +991,10 @@ EAction.getMenu = function(title, objectName, initFunction) {
     var appWin = EAction.getMainWindow();
     var menuBar = appWin.menuBar();
     var menu;
-    for (var i in menuBar.children()) {
-        menu = menuBar.children()[i];
-        if (menu.objectName === objectName) {
+    var children = menuBar.children();
+    for (var i in children) {
+        menu = children[i];
+        if (!isNull(menu) && menu.objectName === objectName) {
             break;
         }
         menu = undefined;
@@ -983,7 +1002,8 @@ EAction.getMenu = function(title, objectName, initFunction) {
     if (isNull(menu)) {
         menu = new QMenu(title, menuBar);
         menu.objectName = objectName;
-        menuBar.addMenu(menu);
+        var action = menuBar.addMenu(menu);
+        action.objectName = objectName + "Action";
         if (initFunction != undefined) {
             initFunction(menu);
         }
@@ -1835,9 +1855,7 @@ EAction.prototype.simulateMouseMoveEvent = function() {
         return;
     }
 
-    if (isFunction(view.getRGraphicsView)) {
-        view = view.getRGraphicsView();
-    }
+    view = getRGraphicsView(view);
 
     if (isNull(view)) {
         return;
@@ -2190,6 +2208,7 @@ EAction.getEntityId = function(di, action, event, preview, selectable) {
         a = menu.addAction(str);
         if (!isNull(icon)) {
             a.icon = icon;
+            a.iconVisibleInMenu = true;
         }
 
         reactor = new Reactor(id);
@@ -2199,12 +2218,9 @@ EAction.getEntityId = function(di, action, event, preview, selectable) {
 
     // show context menu:
     if (!menu.isEmpty()) {
-        var prev = QCoreApplication.testAttribute(Qt.AA_DontShowIconsInMenus);
-        QCoreApplication.setAttribute(Qt.AA_DontShowIconsInMenus, false);
         this.waitingForContextMenu = true;
         menu.exec(new QPoint(QCursor.pos().x(), QCursor.pos().y()+10));
         this.waitingForContextMenu = false;
-        QCoreApplication.setAttribute(Qt.AA_DontShowIconsInMenus, prev);
         di.clearPreview();
     }
 
